Learn R Programming

assignPOP (version 1.3.0)

reduce.allele: Remove low variance alleles (dimensionality reduction)

Description

This function helps remove alleles that have low variance in the data set such that it can speed up further analyses for a large data set (e.g., > 10K SNPs).

Usage

reduce.allele(x, p = 0.95)

Value

This function return the same object as the function read.genpop() except that the number of columns in the matrix [[1]] is reduced and so is the locus name [[3]].

Arguments

x

A returned object (a list) from the function read.genpop().

p

A threshold of variance for the alleles to be removed. For example, if p = 0.95 (default setting), an allele occupied more than 95 percents across all the samples will be removed.